<?php
namespace Ak\Fs\Adapter;

use Hypweb\Flysystem\GoogleDrive\GoogleDriveAdapter;
use League\Flysystem\Adapter;
use League\Flysystem\AdapterInterface;
use Laminas\ServiceManager\AbstractPluginManager;
use Laminas\ServiceManager\Factory\InvokableFactory;

/**
 * Upravlja instancama Filesystem adaptera.
 *
 * @package Ak\Fs
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/fs
 */
final class AdapterPluginManager extends AbstractPluginManager
{
    const CONFIG_KEY = 'fs_adapters';

    /** @var string */
    protected $instanceOf = AdapterInterface::class;

    /** @var string[]  */
    protected $aliases = [
        'local'  => Adapter\Local::class,
        'null'   => Adapter\NullAdapter::class,
        'google' => GoogleDriveAdapter::class,
    ];

    /** @var string[]  */
    protected $factories = [
        Adapter\Local::class       => LocalFactory::class,
        Adapter\NullAdapter::class => InvokableFactory::class,
        GoogleDriveAdapter::class  => GoogleDriveFactory::class,
    ];
}
