<?php
namespace Ak\Fs\Adapter;

use Google\Client;
use Google_Service_Drive;
use Hypweb\Flysystem\GoogleDrive\GoogleDriveAdapter;
use Interop\Container\ContainerInterface;
use League\Flysystem\AdapterInterface;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu Google Drive adaptera.
 *
 * @package Ak\Fs\Adapter
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/fs
 */
final class GoogleDriveFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return AdapterInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $options = $options ?? [];

        $client = new Client();
        $client->setClientId($options['client_id'] ?? null);
        $client->setClientSecret($options['client_secret'] ?? null);
        $client->refreshToken($options['refresh_token']);

        $service = new Google_Service_Drive($client);

        return new GoogleDriveAdapter($service, $options['root_id'] ?? 'root');
    }
}
