<?php
namespace Ak\Fs;

/**
 * Datoteka.
 *
 * @package Ak\Fs
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/fs
 */
class File implements FileInterface
{
    /** @var string */
    private $path;
    /** @var resource */
    private $stream;
    /** @var string */
    private $contents;
    /** @var string */
    private $mimeType;

    /**
     * Konstruktor.
     *
     * @param string $path
     * @param resource $stream
     */
    public function __construct(string $path = null, $stream = null)
    {
        $this->path = $path;
        $this->stream = $stream;
    }

    /**
     * Destruktor.
     */
    public function __destruct()
    {
        if (is_resource($this->stream)) {
            fclose($this->stream);
        }
    }

    /**
     * Vraća sadržaj datoteke.
     *
     * @return string
     */
    public function getContents(): string
    {
        if (null === $this->contents) {
            $this->contents = is_resource($this->stream)
                ? stream_get_contents($this->stream)
                : '';
        }

        return $this->contents;
    }

    /**
     * Postavlja novi sadržaj datoteke.
     *
     * @param string $contents
     */
    public function setContents(string $contents): void
    {
        $this->contents = $contents;
    }

    /**
     * Vraća putanju do datoteke.
     *
     * @return null|string
     */
    public function getPath(): ?string
    {
        return $this->path;
    }

    /**
     * Vraća stream ako postoji.
     *
     * @return null|resource
     */
    public function getResource()
    {
        return $this->stream;
    }

    public function getMimeType(): string
    {
        if (null === $this->mimeType) {
            $finfo = new \finfo(FILEINFO_MIME);
            $this->mimeType = preg_replace('/;.+$/', '', $finfo->buffer($this->getContents()));
        }

        return $this->mimeType;
    }
}