<?php
namespace Ak\Fs;

use Interop\Container\ContainerInterface;
use League\Flysystem\FilesystemInterface;
use Laminas\Hydrator\DelegatingHydrator;
use Laminas\Hydrator\HydratorPluginManager;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu File Loadera.
 *
 * @package Ak\Fs
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/fs
 */
final class FileLoaderFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return FileLoaderInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $fs = $container->get(FilesystemInterface::class);
        $hydrators = $container->get(HydratorPluginManager::class);
        $hydrator = new DelegatingHydrator($hydrators);

        return new $requestedName($fs, $hydrator);
    }
}
