<?php
namespace Ak\Fs;

use Interop\Container\ContainerInterface;
use League\Flysystem\FilesystemInterface;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu File Managera.
 *
 * @package Ak\Fs
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/fs
 */
final class FileManagerFactory implements FactoryInterface
{
    /**
     * Stvara File Manager.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return FileManagerInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['file_manager'] ?? [];
        $fs = $container->get(FilesystemInterface::class);

        $configLoaders = array_unique($config['loaders']);
        unset($configLoaders[array_search('file_loader', $configLoaders)]);
        $configLoaders[] = 'file_loader';

        $loaders = [];

        foreach ($configLoaders as $loader) {
            $loaders[] = $container->get($loader);
        }


        return new FileManager($fs, $loaders);
    }
}
