<?php
namespace Ak\Fs\Service;

use Interop\Container\ContainerInterface;
use League\Flysystem\FilesystemInterface;
use League\Flysystem\MountManager;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu Flysystem Mount Managera.
 *
 * @package Ak\Fs\Service
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/fs
 */
final class MountManagerFactory implements FactoryInterface
{
    /**
     * Stvara instancu.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return FilesystemInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $manager = new MountManager();
        $fsFactory = new FilesystemAbstractFactory();

        $fileSystems = $container->get('config')['fs'];

        foreach ($fileSystems as $prefix => $config) {
            $fs = $fsFactory($container, '', $config);
            $manager->mountFilesystem($prefix, $fs);
        }

        return $manager;
    }
}
