<?php
namespace AkTest\Fs\Adapter;

use Ak\Fs\Adapter\AdapterPluginManager;
use AkTest\Fs\AbstractTestCase;
use Hypweb\Flysystem\GoogleDrive\GoogleDriveAdapter;
use League\Flysystem\Adapter;

/**
 * Class AdapterPluginManagerTest
 *
 * @package AkTest\Fs\Adapter
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/fs
 */
final class AdapterPluginManagerTest extends AbstractTestCase
{
    public function testCanCreateLocalAdapter()
    {
        $container = $this->getContainer();
        $adapters = new AdapterPluginManager($container);

        $options = ['root' => __DIR__];
        /** @var Adapter\Local $local */
        $local = $adapters->get('local', $options);

        $this->assertInstanceOf(Adapter\Local::class, $local);
        $this->assertEquals($options['root'], rtrim($local->getPathPrefix(), '/'));
    }

    public function testCanCreateNullAdapter()
    {
        $container = $this->getContainer();
        $adapters = new AdapterPluginManager($container);

        $null = $adapters->get('null');

        $this->assertInstanceOf(Adapter\NullAdapter::class, $null);
    }

    public function testCanCreateGoogleDriveAdapter()
    {
        $container = $this->getContainer();
        $adapters = new AdapterPluginManager($container);

        /** @var GoogleDriveAdapter $drive */
        $drive = $adapters->get('google', [
            'client_id' => '971305381446-9jsfee4l32dupcjdm5407piabdg1ucti.apps.googleusercontent.com',
            'client_secret' => 'DUMuySvmrx3umHO5X24VqeZS',
            'refresh_token' => '1/SXMtZ4nRF_hPeEWDjPV16xTp6H1xLNcmhItMFj5n9pM',
            'root_id' => '1lJc5_YYzwjDKdr_JdnvfER1modshR8iG',
        ]);

        $this->assertInstanceOf(GoogleDriveAdapter::class, $drive);
    }
}