<?php
namespace AkTest\Fs;

use Ak\Fs\File;
use Ak\Fs\FileInterface;
use Ak\Fs\FileManagerInterface;

/**
 * Class FileManagerTest
 *
 * @package AkTest\Fs
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/fs
 */
final class FileManagerTest extends AbstractTestCase
{
    public function testIsRegistered()
    {
        $container = $this->getContainer();

        $this->assertContainerHasService($container, FileManagerInterface::class, FileManagerInterface::class);
    }

    public function testCanDeleteFiles()
    {
        $filename = __DIR__ . '/data/temp';

        file_put_contents($filename, 'contents');
        $this->assertTrue(file_exists($filename));

        $container = $this->getContainer();
        /** @var FileManagerInterface $manager */
        $manager = $container->get(FileManagerInterface::class);

        $manager->delete('test://temp');

        $this->assertFalse(file_exists($filename));
    }

    public function testCanReadFiles()
    {
        $contents = file_get_contents(__DIR__ . '/data/file');

        $container = $this->getContainer();
        /** @var FileManagerInterface $manager */
        $manager = $container->get(FileManagerInterface::class);

        $file = $manager->get('test://file');

        $this->assertInstanceOf(FileInterface::class, $file);
        $this->assertEquals('test://file', $file->getPath());
        $this->assertEquals($contents, $file->getContents());
    }

    public function testCanWriteFiles()
    {
        $contents = 'some contents';

        $file = new File('test://new-file');
        $file->setContents($contents);

        $container = $this->getContainer();
        /** @var FileManagerInterface $manager */
        $manager = $container->get(FileManagerInterface::class);

        $manager->write($file);

        $this->assertTrue(file_exists(__DIR__ . '/data/new-file'));
        $this->assertEquals($contents, file_get_contents(__DIR__ . '/data/new-file'));

        $manager->delete('test://new-file');
    }
}