<?php
namespace AkTest\Fs;

use Ak\Fs\File;
use Ak\Fs\FileManagerInterface;

/**
 * Class FileTest
 *
 * @package AkTest\Fs
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/fs
 */
final class FileTest extends AbstractTestCase
{
    public function testCanSetPathViaConstructor()
    {
        $file = new File('test://file');

        $this->assertEquals('test://file', $file->getPath());
        $this->assertEquals('', $file->getContents());
    }

    public function testWillCloseTheStreamOnDestruct()
    {
        $stream = fopen(__DIR__ . '/data/file', 'rb');

        /** @noinspection PhpUnusedLocalVariableInspection */
        $file = new File('path', $stream);
        $file = null;

        $this->assertFalse(is_resource($stream));
    }

    public function testCanGetContentsFromStream()
    {
        $contents = file_get_contents(__DIR__ . '/data/file');
        $stream = fopen(__DIR__ . '/data/file', 'rb');

        $file = new File('path', $stream);

        $this->assertEquals($contents, $file->getContents());
    }

    public function testCanReadMimeType()
    {
        $container = $this->getContainer();
        /** @var FileManagerInterface $files */
        $files = $container->get(FileManagerInterface::class);

        $png = $files->get('test://bmw.png');
        $this->assertEquals('image/png', $png->getMimeType());

        $jpeg = $files->get('test://flowers.jpg');
        $this->assertEquals('image/jpeg', $jpeg->getMimeType());

        $text = $files->get('test://file');
        $this->assertEquals('text/plain', $text->getMimeType());
    }
}